/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2017 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  18.03.2017  mifi  First Version.
**************************************************************************/
#if !defined(__TALCPU_SPECIFIC_CAN_H__)
#define __TALCPU_SPECIFIC_CAN_H__

/**************************************************************************
*  Includes
**************************************************************************/

#if defined(CHIP_LPC177X_8X)
#include "lpc1788.h"
#endif

#if defined(CHIP_LPC40XX)
#include "lpc4088.h"
#endif

/**************************************************************************
*  Global Definitions
**************************************************************************/

#if defined(CHIP_LPC177X_8X)

#define CAN_BASE     CAN_BASE_ADDRESS
#define CAN1_BASE    CAN1_BASE_ADDRESS
#define CAN2_BASE    CAN2_BASE_ADDRESS

#define AFMR         AFMR_REG
#define SFF_sa       SFF_sa_REG
#define SFF_GRP_sa   SFF_GRP_sa_REG
#define EFF_sa       EFF_sa_REG
#define EFF_GRP_sa   EFF_GRP_sa_REG
#define ENDofTable   ENDofTable_REG

#define C1ICR        C1ICR_REG
#define C2ICR        C2ICR_REG

#define C1MOD        C1MOD_REG
#define C1GSR        C1GSR_REG
#define C1IER        C1IER_REG

#define C2MOD        C2MOD_REG
#define C2GSR        C2GSR_REG
#define C2IER        C2IER_REG

#endif /* CHIP_LPC177X_8X */


#if defined(CHIP_LPC40XX)

#define CAN_BASE     LPC_CANAFRAM_BASE_ADDRESS
#define CAN1_BASE    LPC_CAN1_BASE_ADDRESS
#define CAN2_BASE    LPC_CAN2_BASE_ADDRESS

#define AFMR         LPC_CANAF_AFMR
#define SFF_sa       LPC_CANAF_SFF_SA
#define SFF_GRP_sa   LPC_CANAF_SFF_GRP_SA
#define EFF_sa       LPC_CANAF_EFF_SA
#define EFF_GRP_sa   LPC_CANAF_EFF_GRP_SA
#define ENDofTable   LPC_CANAF_ENDOFTABLE

#define CAN1IER      LPC_CAN1_IER
#define CAN2IER      LPC_CAN2_IER

#define C1ICR        LPC_CAN1_ICR
#define C2ICR        LPC_CAN2_ICR

#define C1MOD        LPC_CAN1_MOD
#define C1GSR        LPC_CAN1_GSR
#define C1IER        LPC_CAN1_IER

#define C2MOD        LPC_CAN2_MOD
#define C2GSR        LPC_CAN2_GSR
#define C2IER        LPC_CAN2_IER


#define AFMR_AccOff  LPC_CANAF_AFMR_ACCOFF_MASK  

#define C1MOD_RM        LPC_CAN1_MOD_RM_MASK
#define C1CMR_TR        LPC_CAN1_CMR_TR_MASK
#define C1CMR_RRB       LPC_CAN1_CMR_RRB_MASK
#define C1CMR_STB1      LPC_CAN1_CMR_STB1_MASK
#define C1ICR_RI        LPC_CAN1_ICR_RI_MASK
#define C1ICR_TI1       LPC_CAN1_ICR_TI1_MASK
#define C1ICR_EI        LPC_CAN1_ICR_EI_MASK
#define C1ICR_DOI       LPC_CAN1_ICR_DOI_MASK
#define C1IER_RIE       LPC_CAN1_IER_RIE_MASK
#define C1IER_TIE1      LPC_CAN1_IER_TIE1_MASK
#define C1IER_EIE       LPC_CAN1_IER_EIE_MASK
#define C1IER_DOIE      LPC_CAN1_IER_DOIE_MASK
#define C1RFS_FF        LPC_CAN1_RFS_FF_MASK
#define C1RFS_DLC_BIT   LPC_CAN1_RFS_DLC_BIT
#define C1TFI1_FF       LPC_CAN1_TFI1_FF_MASK

#define C2MOD_RM        LPC_CAN2_MOD_RM_MASK
#define C2IER_TIE1      LPC_CAN2_IER_TIE1_MASK


#endif /* CHIP_LPC40XX */


/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

#endif /* !__TALCPU_SPECIFIC_CAN_H__ */

/*** EOF ***/
